@@ -18,43 +18,22 @@ class ValidationError(Exception):
 CONFIG_PREFIX = "autodoc2_"
 
 
-@dc.dataclass
-class RenderConfig:
-    """The configuration for rendering.
-
-    This uses the global, with package level overrides.
-    """
-
-    module_all_regexes: list[re.Pattern[str]]
-    skip_module_regexes: list[re.Pattern[str]]
-    hidden_objects: set[t.Literal["undoc", "dunder", "private", "inherited"]]
-    hidden_regexes: list[re.Pattern[str]]
-    deprecated_module_regexes: list[re.Pattern[str]]
-    module_summary: bool
-    class_docstring: t.Literal["merge", "both"]
-    class_inheritance: bool
-    annotations: bool
-    sort_names: bool
-    replace_annotations: list[tuple[str, str]]
-    replace_bases: list[tuple[str, str]]
-
-
 @dc.dataclass
 class PackageConfig:
     """A package-level config item."""
 
-    # package specific
     path: str = dc.field(
         metadata={
             "help": "The path to the package, "
-            "relative to the source directory (POSIX format)."
+            "relative to the source directory (POSIX format).",
+            "sphinx_type": str,
         }
     )
     from_git_clone: tuple[str, str] | None = dc.field(
         default=None,
         metadata={
             "help": "Clone a git (url, branch/tag)/ "
-            "If using this option the 'path' will be relative to root of the cloned repository."
+            "If using this option the 'path' will be relative to root of the cloned repository.",
         },
     )
     module: str | None = dc.field(
@@ -65,21 +44,26 @@ class PackageConfig:
         },
     )
 
-    # global overrides
-    exclude_dirs: list[str] | None = None
-    exclude_files: list[str] | None = None
-    module_all_regexes: list[re.Pattern[str]] | None = None
-    skip_module_regexes: list[re.Pattern[str]] | None = None
-    hidden_objects: set[
-        t.Literal["undoc", "dunder", "private", "inherited"]
-    ] | None = None
-    hidden_regexes: list[re.Pattern[str]] | None = None
-    deprecated_module_regexes: list[re.Pattern[str]] | None = None
-    module_summary: bool | None = None
-    class_inheritance: bool | None = None
-    class_docstring: t.Literal["merge", "both"] | None = None
-    annotations: bool | None = None
-    sort_names: bool | None = None
+    exclude_dirs: list[str] = dc.field(
+        default_factory=lambda: ["__pycache__"],
+        metadata={
+            "help": "Directories to exclude from module analysis (matched by fnmatch).",
+        },
+    )
+
+    exclude_files: list[str] = dc.field(
+        default_factory=list,
+        metadata={
+            "help": "Files to exclude from module gathering (matched by fnmatch).",
+        },
+    )
+
+    auto_mode: bool = dc.field(
+        default=True,
+        metadata={
+            "help": "Whether to automatically generate documentation for the package.",
+        },
+    )
 
     def as_triple(self) -> t.Iterable[tuple[str, t.Any, dc.Field]]:  # type: ignore[type-arg]
         """Yield triples of (name, value, field)."""
@@ -97,6 +81,7 @@ def _coerce_packages(name: str, item: t.Any) -> list[PackageConfig]:
     # make sure we don't mutate the original (triggers sphinx total rebuild)
     new = [deepcopy(i) for i in item]
     for i, package in enumerate(new[:]):
+        # TODO here we should use the PackageConfig to validate
         if isinstance(package, str):
             new[i] = package = {"path": package}
         if not isinstance(package, dict):
@@ -129,46 +114,12 @@ def _coerce_packages(name: str, item: t.Any) -> list[PackageConfig]:
                 or not all(isinstance(x, str) for x in package[key])
             ):
                 raise ValidationError(f"{name}[{i}][{key!r}] must be a list of strings")
-        for key in (
-            "module_summary",
-            "class_inheritance",
-            "annotations",
-            "sort_names",
-        ):
-            if key in package and not isinstance(package[key], bool):
-                raise ValidationError(f"{name}[{i}][{key!r}] must be a boolean")
-        if "class_docstring" in package and package["class_docstring"] not in (
-            "merge",
-            "both",
-        ):
-            raise ValidationError(
-                f"{name}[{i}]['class_docstring'] must be 'merge' or 'both'"
-            )
-        for key in (
-            "skip_module_regexes",
-            "hidden_regexes",
-            "deprecated_module_regexes",
-            "module_all_regexes",
-        ):
-            if key in package:
-                package[key] = _validate_regex_list(
-                    f"{name}[{i}][{key!r}]", package[key]
-                )
-        if "hidden_objects" in package:
-            package["hidden_objects"] = _validate_hidden_objects(
-                f"{name}[{i}]['hidden_objects']", package["hidden_objects"]
-            )
+        if "autodoc" in package and not isinstance(package["autodoc"], bool):
+            raise ValidationError(f"{name}[{i}]['autodoc'] must be a boolean")
 
     return [PackageConfig(**p) for p in new]
 
 
-def _validate_string_list(name: str, item: t.Any) -> list[str]:
-    """Validate that an item is a string."""
-    if not isinstance(item, list) or not all(isinstance(x, str) for x in item):
-        raise ValidationError(f"{name!r} must be a list of string")
-    return item
-
-
 def _validate_replace_list(name: str, item: t.Any) -> list[t.Tuple[str, str]]:
     """Validate that an item is a list of tuples."""
     if not isinstance(item, list) or not all(
@@ -204,6 +155,23 @@ def _validate_regex_list(name: str, item: t.Any) -> list[t.Pattern[str]]:
     return compiled
 
 
+def _validate_list_tuple_regex_str(
+    name: str, item: t.Any
+) -> list[tuple[t.Pattern[str], str]]:
+    """Validate that an item is a list of (regex, str) tuples."""
+    if not isinstance(item, list) or not all(
+        isinstance(x, (list, tuple)) and len(x) == 2 for x in item
+    ):
+        raise ValidationError(f"{name!r} must be a list of (string, string) tuples")
+    compiled = []
+    for i, (regex, replacement) in enumerate(item):
+        try:
+            compiled.append((re.compile(regex), replacement))
+        except re.error as exc:
+            raise ValidationError(f"{name}[{i}] is not a valid regex: {exc}")
+    return compiled
+
+
 def _load_renderer(name: str, item: t.Any) -> type[RendererBase]:
     """Load a renderer class."""
     from autodoc2.render.base import RendererBase
@@ -264,15 +232,16 @@ class Config:
         default_factory=list,
         metadata={
             "help": (
-                "The packages to document. "
+                "The packages to analyse. "
                 "Each item can be a simple string, "
                 "pointing to the package path, "
                 "relative to the source directory (in POSIX format), "
                 "or it can be a dictionary with more fine-grained control "
                 "(see {ref}`config:package`))."
             ),
-            "sphinx_type": (list,),
+            "sphinx_type": list,
             "sphinx_validate": _coerce_packages,
+            "doc_type": "list[str | dict]",
             "category": "required",
         },
     )
@@ -284,31 +253,11 @@ class Config:
                 "The root output directory for the documentation, "
                 "relative to the source directory (in POSIX format)."
             ),
-            "sphinx_type": (str,),
+            "sphinx_type": str,
             "category": "render",
         },
     )
 
-    exclude_dirs: list[str] = dc.field(
-        default_factory=lambda: ["__pycache__"],
-        metadata={
-            "help": "Directories to exclude from module analysis (matched by fnmatch).",
-            "sphinx_type": (list,),
-            "sphinx_validate": _validate_string_list,
-            "category": "analysis",
-        },
-    )
-
-    exclude_files: list[str] = dc.field(
-        default_factory=list,
-        metadata={
-            "help": "Files to exclude from module gathering (matched by fnmatch).",
-            "sphinx_type": (list,),
-            "sphinx_validate": _validate_string_list,
-            "category": "analysis",
-        },
-    )
-
     render_plugin: type[RendererBase] = dc.field(
         default_factory=(lambda: _load_renderer("render_plugin", "rst")),
         metadata={
@@ -319,9 +268,10 @@ class Config:
                 "or a string pointing to a class that inherits from `RendererBase`, "
                 "such as `mypackage.mymodule.MyRenderer`."
             ),
-            "sphinx_type": (str,),
+            "sphinx_type": str,
             "sphinx_default": "rst",
             "sphinx_validate": _load_renderer,
+            "doc_type": "str",
             "category": "render",
         },
     )
@@ -330,8 +280,9 @@ class Config:
         default_factory=list,
         metadata={
             "help": "A list of (regex, renderer) to use for specific modules",
-            "sphinx_type": (list,),
+            "sphinx_type": list,
             "sphinx_validate": _load_regex_renderers,
+            "doc_type": "list[tuple[str, str]]",
             "category": "render",
         },
     )
@@ -339,10 +290,12 @@ class Config:
     module_all_regexes: list[t.Pattern[str]] = dc.field(
         default_factory=list,
         metadata={
-            "help": "Whether to use the `__all__` in a module, "
-            "to determine what children to document",
-            "sphinx_type": (list,),
+            "help": "Regexes which match fully qualified module names, "
+            "to specify they should use the `__all__` when "
+            "determining which children to document",
+            "sphinx_type": list,
             "sphinx_validate": _validate_regex_list,
+            "doc_type": "list[str]",
             "category": "render",
         },
     )
@@ -350,9 +303,10 @@ class Config:
     skip_module_regexes: list[t.Pattern[str]] = dc.field(
         default_factory=list,
         metadata={
-            "help": "Regexes which match against module/package names, to skip them",
-            "sphinx_type": (list,),
+            "help": "Regexes which match fully qualified module/package names, to skip them",
+            "sphinx_type": list,
             "sphinx_validate": _validate_regex_list,
+            "doc_type": "list[str]",
             "category": "render",
         },
     )
@@ -370,8 +324,9 @@ class Config:
                 "- `private`: single-underscore methods, e.g. `_private`\n"
                 "- `inherited`: inherited class methods\n"
             ),
-            "sphinx_type": (list,),
+            "sphinx_type": list,
             "sphinx_validate": _validate_hidden_objects,
+            "doc_type": 'list["undoc" | "dunder" | "private" | "inherited"]',
             "category": "render",
         },
     )
@@ -379,9 +334,19 @@ class Config:
     hidden_regexes: list[t.Pattern[str]] = dc.field(
         default_factory=list,
         metadata={
-            "help": "Regexes which match against object names, to mark them as hidden",
-            "sphinx_type": (list,),
+            "help": "Regexes which match against fully qualified names, to mark them as hidden",
+            "sphinx_type": list,
             "sphinx_validate": _validate_regex_list,
+            "doc_type": "list[str]",
+            "category": "render",
+        },
+    )
+
+    no_index: bool = dc.field(
+        default=False,
+        metadata={
+            "help": "Do not generate a cross-reference index.",
+            "sphinx_type": bool,
             "category": "render",
         },
     )
@@ -390,8 +355,9 @@ class Config:
         default_factory=list,
         metadata={
             "help": "Regexes which match against module names, to mark them as deprecated",
-            "sphinx_type": (list,),
+            "sphinx_type": list,
             "sphinx_validate": _validate_regex_list,
+            "doc_type": "list[str]",
             "category": "render",
         },
     )
@@ -400,7 +366,20 @@ class Config:
         default=True,
         metadata={
             "help": "Whether to include a per-module summary.",
-            "sphinx_type": (bool,),
+            "sphinx_type": bool,
+            "category": "render",
+        },
+    )
+
+    docstring_parser_regexes: list[tuple[t.Pattern[str], str]] = dc.field(
+        default_factory=list,
+        metadata={
+            "help": "Match fully qualified names against regexes to use a specific parser. "
+            "The parser can be one of 'rst', 'myst', or the fully qualified name of a custom parser class. "
+            "The first match is used. ",
+            "sphinx_type": list,
+            "sphinx_validate": _validate_list_tuple_regex_str,
+            "doc_type": "list[tuple[str, str]]",
             "category": "render",
         },
     )
@@ -414,7 +393,8 @@ class Config:
                 "and the `__init__` method is omitted."
                 "If `both`, then the `__init__` method is included separately."
             ),
-            "sphinx_type": (str,),
+            "sphinx_type": str,
+            "doc_type": '"merge" | "both"',
             "category": "render",
         },
     )
@@ -423,7 +403,7 @@ class Config:
         default=True,
         metadata={
             "help": "Whether to document class inheritance.",
-            "sphinx_type": (bool,),
+            "sphinx_type": bool,
             "category": "render",
         },
     )
@@ -432,7 +412,18 @@ class Config:
         default=True,
         metadata={
             "help": "Whether to include annotations.",
-            "sphinx_type": (bool,),
+            "sphinx_type": bool,
+            "category": "render",
+        },
+    )
+
+    docstrings: t.Literal["all", "direct", "none"] = dc.field(
+        default="direct",
+        metadata={
+            "help": "Which objects to include docstrings for. "
+            "'direct' means only from objects that are not inherited.",
+            "sphinx_type": str,
+            "doc_type": '"all" | "direct"',
             "category": "render",
         },
     )
@@ -441,7 +432,7 @@ class Config:
         default=False,
         metadata={
             "help": "Whether to sort by name, when documenting, otherwise order by source",
-            "sphinx_type": (bool,),
+            "sphinx_type": bool,
             "category": "render",
         },
     )
@@ -450,7 +441,7 @@ class Config:
         default_factory=list,
         metadata={
             "help": "List of (from, to) for annotation replacements",
-            "sphinx_type": (list,),
+            "sphinx_type": list,
             "sphinx_validate": _validate_replace_list,
             "category": "render",
         },
@@ -460,7 +451,7 @@ class Config:
         default_factory=list,
         metadata={
             "help": "List of (from, to) for class base replacements",
-            "sphinx_type": (list,),
+            "sphinx_type": list,
             "sphinx_validate": _validate_replace_list,
             "category": "render",
         },
@@ -479,7 +470,7 @@ class Config:
             "   {{ package }}\n"
             "{%- endfor %}\n"
             "\n"
-            ".. [#f1] Created with `sphinx-autodoc2`\n"
+            ".. [#f1] Created with `sphinx-autodoc2 <https://github.com/chrisjsewell/sphinx-autodoc2>`_\n"
             "\n"
         ),
         metadata={
@@ -489,65 +480,21 @@ class Config:
                 "The template will be passed a ``top_level`` variable, "
                 "which is a list of top-level package/module names."
             ),
-            "sphinx_type": t.Optional[str],
+            "sphinx_type": (str, type(None)),
             "category": "render",
         },
     )
 
+    # TODO regexes
+    # module_summary: bool | None = None
+    # class_inheritance: bool | None = None
+    # class_docstring: t.Literal["merge", "both"] | None = None
+    # annotations: bool | None = None
+    # sort_names: bool | None = None
+    # docstrings
+
     def as_triple(self) -> t.Iterable[tuple[str, t.Any, dc.Field]]:  # type: ignore[type-arg]
         """Yield triples of (name, value, field)."""
         fields = {f.name: f for f in dc.fields(self.__class__)}
         for name, value in dc.asdict(self).items():
             yield name, value, fields[name]
-
-    def to_render_config(self, pkg_index: int | None) -> RenderConfig:
-        """Convert a module level render config."""
-        # TODO config could also be specific to the module?
-        if pkg_index is None:
-            return RenderConfig(
-                skip_module_regexes=self.skip_module_regexes,
-                hidden_objects=self.hidden_objects,
-                hidden_regexes=self.hidden_regexes,
-                deprecated_module_regexes=self.deprecated_module_regexes,
-                module_summary=self.module_summary,
-                class_docstring=self.class_docstring,
-                class_inheritance=self.class_inheritance,
-                annotations=self.annotations,
-                sort_names=self.sort_names,
-                module_all_regexes=self.module_all_regexes,
-                replace_annotations=self.replace_annotations,
-                replace_bases=self.replace_bases,
-            )
-        pkg = self.packages[pkg_index]
-        return RenderConfig(
-            skip_module_regexes=self.skip_module_regexes
-            if pkg.skip_module_regexes is None
-            else pkg.skip_module_regexes,
-            hidden_objects=self.hidden_objects
-            if pkg.hidden_objects is None
-            else pkg.hidden_objects,
-            hidden_regexes=self.hidden_regexes
-            if pkg.hidden_regexes is None
-            else pkg.hidden_regexes,
-            deprecated_module_regexes=self.deprecated_module_regexes
-            if pkg.deprecated_module_regexes is None
-            else pkg.deprecated_module_regexes,
-            module_summary=self.module_summary
-            if pkg.module_summary is None
-            else pkg.module_summary,
-            class_docstring=self.class_docstring
-            if pkg.class_docstring is None
-            else pkg.class_docstring,
-            class_inheritance=self.class_inheritance
-            if pkg.class_inheritance is None
-            else pkg.class_inheritance,
-            annotations=self.annotations
-            if pkg.annotations is None
-            else pkg.annotations,
-            sort_names=self.sort_names if pkg.sort_names is None else pkg.sort_names,
-            module_all_regexes=self.module_all_regexes
-            if pkg.module_all_regexes is None
-            else pkg.module_all_regexes,
-            replace_annotations=self.replace_annotations,
-            replace_bases=self.replace_bases,
-        )
